==> igniteui-react-charts-16.15.1.tgz: package/esm5/lib/AccumulationDistributionIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AccumulationDistributionIndicatorStrategy } from "./AccumulationDistributionIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AccumulationDistributionIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicator, _super);
    function AccumulationDistributionIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicator.prototype.get_t4 = function () {
        return new AccumulationDistributionIndicatorStrategy();
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "t4", {
        get: function () {
            return this.get_t4();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.prototype.get_uh = function () {
        return AccumulationDistributionIndicator.$;
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.$t = markType(AccumulationDistributionIndicator, 'AccumulationDistributionIndicator', StrategyBasedIndicator.$);
    return AccumulationDistributionIndicator;
}(StrategyBasedIndicator));
export { AccumulationDistributionIndicator };

==> igniteui-react-charts-16.16.3.tgz: package/esm5/lib/AccumulationDistributionIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { AccumulationDistributionIndicatorStrategy } from "./AccumulationDistributionIndicatorStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var AccumulationDistributionIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AccumulationDistributionIndicator, _super);
    function AccumulationDistributionIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AccumulationDistributionIndicator.prototype.get_uh = function () {
        return new AccumulationDistributionIndicatorStrategy();
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "uh", {
        get: function () {
            return this.get_uh();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.prototype.get_uu = function () {
        return AccumulationDistributionIndicator.$;
    };
    Object.defineProperty(AccumulationDistributionIndicator.prototype, "uu", {
        get: function () {
            return this.get_uu();
        },
        enumerable: false,
        configurable: true
    });
    AccumulationDistributionIndicator.$t = markType(AccumulationDistributionIndicator, 'AccumulationDistributionIndicator', StrategyBasedIndicator.$);
    return AccumulationDistributionIndicator;
}(StrategyBasedIndicator));
export { AccumulationDistributionIndicator };
